@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 import json
-import sys
+import os
 import logging
 import requests
 import socket
@@ -17,6 +17,9 @@ ERROR = "error"
 SUCCESS = "SUCCESS"
 FAILED = "FAILED"
 
+# Environment Variables
+
+
 ################################################################################
 # Queries
 ################################################################################
@@ -38,23 +41,29 @@ HEADERS = {
 }
 
 
-# TODO - Add user validation
-
 ################################################################################
 # Athena Client
 ################################################################################
 
 class AthenaClient:
+    _USER_NAME: str = 'USER_NAME'
+    _ACCESS_TOKEN: str = 'ACCESS_TOKEN'
+    _CCF_SERVICES_HOST: str = 'CCF_SERVICES_HOST'
 
-    def __init__(self, user_name, password):
-        self._user_name = user_name
-        self._password = password
+    def __init__(self):
+        self._user_name = os.getenv(self._USER_NAME, None) or 'Karthik'
+        self._access_token = os.getenv(self._ACCESS_TOKEN, None) or '1'
+        self._ccf_services_host = os.getenv(self._CCF_SERVICES_HOST, None) or SERVICE_URL
+
+    def connect(self):
+        # TODO - Add user validation
+        return "You're now connected..."
 
     def databases(self, result_as_df=True):
         """Returns all the schemas available in Athena"""
         try:
-            payload = json.dumps({"user_name": self._user_name, "password": self._password})
-            r = requests.post(SERVICE_URL + API_GET_ATHENA_DATABASES, data=payload, headers=HEADERS)
+            payload = json.dumps({"user_name": self._user_name, "password": self._access_token})
+            r = requests.post(self._ccf_services_host + API_GET_ATHENA_DATABASES, data=payload, headers=HEADERS)
             response = r.json()
             if response[STATUS] == SUCCESS:
                 if result_as_df:
@@ -64,24 +73,20 @@ class AthenaClient:
                     return response[RESULT]
             else:
                 return response[RESULT]
-        except requests.exceptions.HTTPError as err_h:
-            # logger.error(msg=err_h)
+        except requests.exceptions.HTTPError:
             raise Exception("Http error occurred") from None
-        except requests.exceptions.ConnectionError as err_c:
-            # logger.error(msg=err_c)
+        except requests.exceptions.ConnectionError:
             raise ConnectionError("Connection error occurred") from None
-        except requests.exceptions.Timeout as err_t:
-            # logger.error(msg=err_t)
+        except requests.exceptions.Timeout:
             raise TimeoutError("Request timed out...") from None
-        except requests.exceptions.RequestException as err:
-            # logger.error(msg=err)
+        except requests.exceptions.RequestException:
             raise Exception("RequestException occurred") from None
 
     def tables(self, schema_name, result_as_df=True):
         """Returns all the tables present in a schema"""
         try:
-            payload = json.dumps({"user_name": self._user_name, "password": self._password, "schema_name": schema_name})
-            r = requests.post(SERVICE_URL + API_GET_ATHENA_TABLES, data=payload, headers=HEADERS)
+            payload = json.dumps({"user_name": self._user_name, "password": self._access_token, "schema_name": schema_name})
+            r = requests.post(self._ccf_services_host + API_GET_ATHENA_TABLES, data=payload, headers=HEADERS)
             response = r.json()
             if response[STATUS] == SUCCESS:
                 if result_as_df:
@@ -91,25 +96,21 @@ class AthenaClient:
                     return response[RESULT]
             else:
                 return response[RESULT]
-        except requests.exceptions.HTTPError as err_h:
-            # logger.error(msg=err_h)
+        except requests.exceptions.HTTPError:
             raise Exception("Http error occurred") from None
-        except requests.exceptions.ConnectionError as err_c:
-            # logger.error(msg=err_c)
+        except requests.exceptions.ConnectionError:
             raise ConnectionError("Connection error occurred") from None
-        except requests.exceptions.Timeout as err_t:
-            # logger.error(msg=err_t)
+        except requests.exceptions.Timeout:
             raise TimeoutError("Request timed out...") from None
-        except requests.exceptions.RequestException as err:
-            # logger.error(msg=err)
+        except requests.exceptions.RequestException:
             raise Exception("RequestException occurred") from None
 
     def top(self, schema_name, table_name, limit=None, result_as_df=True):
         """Returns records from a table"""
         try:
-            payload = json.dumps({"user_name": self._user_name, "password": self._password, "schema_name": schema_name,
+            payload = json.dumps({"user_name": self._user_name, "password": self._access_token, "schema_name": schema_name,
                                   "table_name": table_name, "limit": limit})
-            r = requests.post(SERVICE_URL + API_QUERY_ATHENA_TABLE, data=payload, headers=HEADERS)
+            r = requests.post(self._ccf_services_host + API_QUERY_ATHENA_TABLE, data=payload, headers=HEADERS)
             response = r.json()
             if response[STATUS] == SUCCESS:
                 if result_as_df:
@@ -119,25 +120,21 @@ class AthenaClient:
                     return response[RESULT]
             else:
                 return response[RESULT]
-        except requests.exceptions.HTTPError as err_h:
-            # logger.error(msg=err_h)
+        except requests.exceptions.HTTPError:
             raise Exception("Http error occurred") from None
-        except requests.exceptions.ConnectionError as err_c:
-            # logger.error(msg=err_c)
+        except requests.exceptions.ConnectionError:
             raise ConnectionError("Connection error occurred") from None
-        except requests.exceptions.Timeout as err_t:
-            # logger.error(msg=err_t)
+        except requests.exceptions.Timeout:
             raise TimeoutError("Request timed out...") from None
-        except requests.exceptions.RequestException as err:
-            # logger.error(msg=err)
+        except requests.exceptions.RequestException:
             raise Exception("RequestException occurred") from None
 
     def run_query(self, query_string, result_as_df=True):
         """Run a specified query"""
         try:
             payload = json.dumps(
-                {"user_name": self._user_name, "password": self._password, "query_string": query_string})
-            r = requests.post(SERVICE_URL + API_RUN_QUERY_ON_ATHENA, data=payload, headers=HEADERS)
+                {"user_name": self._user_name, "password": self._access_token, "query_string": query_string})
+            r = requests.post(self._ccf_services_host + API_RUN_QUERY_ON_ATHENA, data=payload, headers=HEADERS)
             response = r.json()
             if response[STATUS] == SUCCESS:
                 if result_as_df:
@@ -147,15 +144,11 @@ class AthenaClient:
                     return response[RESULT]
             else:
                 return response[RESULT]
-        except requests.exceptions.HTTPError as err_h:
-            # logger.error(msg=err_h)
+        except requests.exceptions.HTTPError:
             raise Exception("Http error occurred") from None
-        except requests.exceptions.ConnectionError as err_c:
-            # logger.error(msg=err_c)
+        except requests.exceptions.ConnectionError:
             raise ConnectionError("Connection error occurred") from None
-        except requests.exceptions.Timeout as err_t:
-            # logger.error(msg=err_t)
+        except requests.exceptions.Timeout:
             raise TimeoutError("Request timed out...") from None
-        except requests.exceptions.RequestException as err:
-            # logger.error(msg=err)
+        except requests.exceptions.RequestException:
             raise Exception("RequestException occurred") from None
